pub struct SelectionEntry {
pub zotero_key: Option<String>,
pub openalex_id: Option<String>,
pub doi: Option<String>,
pub title: Option<String>,
pub authors: Option<Vec<String>>,
pub year: Option<u32>,
pub issn: Option<Vec<String>>,
pub isbn: Option<Vec<String>>,
}Expand description
A single paper in a selection. Stores as much metadata as resolved.
If zotero_key is None, the paper has not been matched to the local Zotero
library; metadata can be used later to prompt the user to download it.
Fields
zotero_key: Option<String>openalex_id: Option<String>doi: Option<String>title: Option<String>year: Option<u32>issn: Option<Vec<String>>isbn: Option<Vec<String>>Trait Implementations
Sourceimpl Clone for SelectionEntry
impl Clone for SelectionEntry
Sourcefn clone(&self) -> SelectionEntry
fn clone(&self) -> SelectionEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SelectionEntry
impl Debug for SelectionEntry
Sourceimpl<'de> Deserialize<'de> for SelectionEntry
impl<'de> Deserialize<'de> for SelectionEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more