pub struct ExtractionMeta {
pub item_key: String,
pub zotero_user_id: Option<String>,
pub title: Option<String>,
pub authors: Option<Vec<String>>,
pub item_type: Option<String>,
pub date: Option<String>,
pub doi: Option<String>,
pub url: Option<String>,
pub publication_title: Option<String>,
pub extracted_at: Option<String>,
pub processing_mode: Option<String>,
pub pdf_source: Option<Value>,
}Expand description
Metadata written alongside each DataLab extraction cache entry as meta.json.
All fields except item_key are Option so that the struct can be read
from older cache entries that may be missing fields.
Fields
item_key: Stringzotero_user_id: Option<String>title: Option<String>item_type: Option<String>date: Option<String>doi: Option<String>url: Option<String>publication_title: Option<String>extracted_at: Option<String>processing_mode: Option<String>pdf_source: Option<Value>Trait Implementations
Sourceimpl Clone for ExtractionMeta
impl Clone for ExtractionMeta
Sourcefn clone(&self) -> ExtractionMeta
fn clone(&self) -> ExtractionMeta
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionMeta
impl Debug for ExtractionMeta
Sourceimpl<'de> Deserialize<'de> for ExtractionMeta
impl<'de> Deserialize<'de> for ExtractionMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more